/*
-------------------------------------------------------------------------------
    This file is a part of the Vst Preset Generator
    Copyright (C) 2007  Francois Mazen

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-------------------------------------------------------------------------------
  Name: maindialog.h
  Author: Francois Mazen
  Date: 28/05/07 16:25
  Description: MainDialog class header
-------------------------------------------------------------------------------
*/

#ifndef MAINDIALOG_H
#define MAINDIALOG_H


#include <QMainWindow>
#include <QObject>
#include <QList>

#include "vstpresetgenerator.h"
#include "fxheader.h"
#include "vpgxml.h"
#include "vpgvsthost.h"
#include "filetypedialog.h"
#include "parammanager.h"
#include "paramvaluedelegate.h"
#include "randommodedelegate.h"
#include "vpglanguagechooser.h"

class QPushButton;
class QLabel;
class QWidget;
class QRadioButton;
class QSpinBox;
class QFile;
class QTableWidget;
class QScrollArea;
class QVBoxLayout;
class QFrame;
class QListView;
class QPixmap;
class QSplashScreen;
class QProgressBar;
class QTableView;
class QSettings;


//-----------------------------------------------------------------------------

class MainDialog : public QMainWindow
{
      Q_OBJECT

public:
       MainDialog(QWidget *parent = 0);
       void closeEvent(QCloseEvent* event);

signals:
        void validHeader(FxHeaderStruct* data);

private slots:

       void GeneratePreset();
       void ShowLabelHeader(FxHeaderStruct* data);
       void UpdateParamList(bool isHeaderValid);
       void OpenVstList();
       void SaveVstList();
       void NewVstList();
       void ShowCopyright();

       void ImportParamFromVstOrPreset(); 	//selection
       void LoadParamFromVst(QString fileName); 			//from dll file
       void OpenPreset(QString fileName);					//from fxp or fxb file

       void SetGlobalRandomMethod(eRandomMode method);
       void SetGlobalRandomMethodUniform();
       void SetGlobalRandomMethodNormal();
       void SetGlobalRandomMethodConstant();
       void SetGlobalRandomMethodTotal();

private:
    //functions:
    void WriteProgram(QFile *file, qint32 no_program);
    void WriteBank(QFile *file, qint32 nb_programs);
    void WriteProgramChunk(QFile *file, qint32 no_program);
    void WriteBankChunk(QFile *file, qint32 nb_programs);

    void dragEnterEvent(QDragEnterEvent *event);    //from Qt
    void dropEvent(QDropEvent *event);               //from Qt

	bool LoadVst(QString fileName);

    //Buttons
    QPushButton *btnGen;


    //Toolbars
    QToolBar *vstImportToolBar;
    QToolBar *vstListToolBar;
    QToolBar *randomMethodToolBar;

    //Labels
    QLabel *headerDescription;


    //list
    QListView *vstList;

    //Image
    QPixmap const *vpgLogo;

    //Progress Bar
    QProgressBar *progressBar;

    //Our class to manage header parameters
    FxHeader *fxHeader;


    //Our object to read and save xml files
    VpgXml *vpgXml;


    //Vst host
    VpgVstHost *vpgVstHost;

    //Dialog to choice the type of the file
    FileTypeDialog *fileTypeDialog;

    //Table to display parameters values
    QTableView *paramTable;
    ParamManager *paramManager;
    ParamValueDelegate *paramValueDelegate;
    RandomModeDelegate *randomModeDelegate;

    //Object to save settings of the session
    QSettings *vpgSettings;
    QString pathVpg;
    QString pathVst;
    QString pathPatch;

    //the language chooser
    VpgLanguageChooser *vpgLanguageChooser;
    QString languageStr;
    QString translatorStr;



};



#endif //MAINDIALOG_H
